@@ -38,19 +38,24 @@
         return metaContent || '';
     }
 
-    // create tweet text from content of <meta name="DC.title"> and <meta name="DC.creator">
+    // create tweet text from content of <meta name="DC.description">,
+    // or <meta name="DC.title"> and <meta name="DC.creator">,
     // fallback to content of <title> tag
     function getTweetText() {
+        var text = '';
+        var description = getMeta('DC.description');
         var title = getMeta('DC.title');
         var creator = getMeta('DC.creator');
 
-        if (title.length > 0 && creator.length > 0) {
-            title += ' - ' + creator;
+        if (description.length > 0) {
+            text = description;
+        } else if (title.length > 0 && creator.length > 0) {
+            text = title + ' - ' + creator;
         } else {
-            title = $('title').text();
+            text = $('title').text();
         }
 
-        return encodeURIComponent(title);
+        return encodeURIComponent(text);
     }
 
     // build URI from rel="canonical" or document.location
@@ -105,6 +110,8 @@
                     'display_name'      : 'Twitter',
                     'referrer_track'    : '',
                     'tweet_text'        : getTweetText,
+                    'short_url'         : '',
+                    'hashtags'          : '',
                     'language'          : 'en'
                 },
                 'gplus' : {
@@ -204,9 +211,14 @@
                 // 120 is the max character count left after twitters automatic url shortening with t.co
                 text = abbreviateText(text, '120');
 
-                var twitter_enc_uri = encodeURIComponent(uri + options.services.twitter.referrer_track);
+                var twitter_url = options.services.twitter.short_url;
+                if (twitter_url.length == 0) {
+                    twitter_url = uri;
+                }
+                var twitter_enc_uri = encodeURIComponent(twitter_url + options.services.twitter.referrer_track);
                 var twitter_count_url = encodeURIComponent(uri);
-                var twitter_code = '<iframe allowtransparency="true" frameborder="0" scrolling="no" src="http://platform.twitter.com/widgets/tweet_button.html?url=' + twitter_enc_uri + '&amp;counturl=' + twitter_count_url + '&amp;text=' + text + '&amp;count=horizontal&amp;lang=' + options.services.twitter.language + '" style="width:130px; height:25px;"></iframe>';
+                var twitter_hashtags = encodeURIComponent(options.services.twitter.hashtags);
+                var twitter_code = '<iframe allowtransparency="true" frameborder="0" scrolling="no" src="http://platform.twitter.com/widgets/tweet_button.html?url=' + twitter_enc_uri + '&amp;hashtags=' + twitter_hashtags + '&amp;counturl=' + twitter_count_url + '&amp;text=' + text + '&amp;count=horizontal&amp;lang=' + options.services.twitter.language + '" style="width:130px; height:25px;"></iframe>';
                 var twitter_dummy_btn = '<img src="' + options.services.twitter.dummy_img + '" alt="&quot;Tweet this&quot;-Dummy" class="tweet_this_dummy" />';
 
                 context.append('<li class="twitter help_info"><span class="info">' + options.services.twitter.txt_info + '</span><span class="switch off">' + options.services.twitter.txt_twitter_off + '</span><div class="tweet dummy_btn">' + twitter_dummy_btn + '</div></li>');
