@@ -1,8 +1,15 @@
+# -*- coding: utf-8 -*-
+
+import json
+import urllib
+import httplib2
+
 from cgi import escape
 
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.CMFPlone.utils import safe_unicode
 from plone.app.layout.viewlets.common import ViewletBase
+from plone.memoize import ram
 
 from Acquisition import aq_inner
 from zope.component import getMultiAdapter, getUtility
@@ -48,7 +55,8 @@ class OpenGraph(ViewletBase):
             self.og_url = escape(safe_unicode(context.absolute_url()))
         except:pass
 
-    def socialButtonsEnabled(self):
+    @property
+    def social_buttons_enabled(self):
         try:
             return self.context.Schema()['socialButtons'].get(self.context)
         except:
@@ -64,64 +72,135 @@ class Buttons(ViewletBase):
 
         self.language = portal_state.language().split('-')[0].split('_')[0]
 
-    def socialButtonsEnabled(self):
+    @property
+    def social_buttons_enabled(self):
         try:
             return self.context.Schema()['socialButtons'].get(self.context)
         except:
             return False
 
-    def twoClickEnabled(self):
+    @property
+    def two_click_enabled(self):
         try:
             settings = getUtility(ISocialConfiguration)
             return settings.two_click_buttons
         except:
             return False
 
+    @ram.cache(lambda method, obj, url: url)
+    def shorten_url(self, url):
+        data = {
+            'longUrl' : url,
+        }
+        try:
+            h = httplib2.Http()
+            body = json.dumps(data)
+            resp, content = h.request(
+                "https://www.googleapis.com/urlshortener/v1/url", "POST",
+                body=body,
+                headers={
+                    'content-type':'application/json',
+                },
+            )
+            return json.loads(content).get('id', url)
+        except Exception,e:
+            return url
+
+    @property
+    def twitter_hashtags(self):
+        try:
+            context_tags = self.context.Schema()['twitterHashtags'].get(self.context).split(',')
+        except:
+            context_tags = []
+
+        try:
+            global_tags = getUtility(ISocialConfiguration).twitter_hashtags.split(',')
+        except:
+            global_tags = []
+
+        tags = []
+        for tag in context_tags + global_tags:
+            tags.append(tag.strip())
+        return ','.join(tags)
+
+
+    @property
+    def facebook_status(self):
+        try:
+            return getUtility(ISocialConfiguration).enable_facebook and 'on' or 'off'
+        except:
+            return 'on'
+
+    @property
+    def googleplus_status(self):
+        try:
+            return getUtility(ISocialConfiguration).enable_gplus and 'on' or 'off'
+        except:
+            return 'on'
+
+    @property
+    def twitter_status(self):
+        try:
+            return getUtility(ISocialConfiguration).enable_twitter and 'on' or 'off'
+        except:
+            return 'on'
+
+    @property
+    def linkedin_status(self):
+        try:
+            return getUtility(ISocialConfiguration).enable_linkedin and 'on' or 'off'
+        except:
+            return 'on'
+
     def two_click_import_script(self):
         language = self.language
         facebook_language = self.get_facebook_langcode()
 
         code = """
-        (function($) {
-            $(document).ready(function() {
-              if($('#socialshareprivacy').length > 0){
-                 $('#socialshareprivacy').socialSharePrivacy({
-                    'services' : {
-                        'facebook' : {
-                            'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(facebook_dummy_image)s',
-                            'txt_info'          : '%(facebook_info_text)s',
-                            'txt_fb_off'        : '%(facebook_disconnected)s',
-                            'txt_fb_on'         : '%(facebook_connected)s',
-                            'language'          : '%(facebook_language)s',
-                        },
-                        'twitter' : {
-                            'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(twitter_dummy_image)s',
-                            'txt_info'          : '%(twitter_info_text)s',
-                            'txt_twitter_off'   : '%(twitter_disconnected)s',
-                            'txt_twitter_on'    : '%(twitter_connected)s',
-                            'language'          : '%(language)s'
-                        },
-                        'gplus' : {
-                            'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(googleplus_dummy_image)s',
-                            'txt_info'          : '%(googleplus_info_text)s',
-                            'txt_gplus_off'     : '%(googleplus_disconnected)s',
-                            'txt_gplus_on'      : '%(googleplus_connected)s',
-                            'language'          : '%(language)s'
-                        },
-                        'linkedin' : {
-                            'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(linkedin_dummy_image)s',
-                            'txt_info'          : '%(linkedin_info_text)s',
-                            'txt_linkedin_off'  : '%(linkedin_disconnected)s',
-                            'txt_linkedin_on'   : '%(linkedin_connected)s',
-                            'language'          : '%(language)s'
-                        }
+        jQuery(document).ready(function($) {
+          if($('#socialshareprivacy').length > 0){
+             $('#socialshareprivacy').socialSharePrivacy({
+                'services' : {
+                    'facebook' : {
+                        'status'            : '%(facebook_status)s',
+                        'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(facebook_dummy_image)s',
+                        'txt_info'          : '%(facebook_info_text)s',
+                        'txt_fb_off'        : '%(facebook_disconnected)s',
+                        'txt_fb_on'         : '%(facebook_connected)s',
+                        'language'          : '%(facebook_language)s'
                     },
-                    'txt_help'          : '%(txt_help)s',
-                    'settings_perma'    : '%(settings_perma)s'
-                 });
-              }
-            });
-        })(jQuery);
+                    'twitter' : {
+                        'status'            : '%(twitter_status)s',
+                        'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(twitter_dummy_image)s',
+                        'txt_info'          : '%(twitter_info_text)s',
+                        'txt_twitter_off'   : '%(twitter_disconnected)s',
+                        'txt_twitter_on'    : '%(twitter_connected)s',
+                        'language'          : '%(language)s',
+                        'hashtags'          : '%(twitter_hashtags)s',
+                        'short_url'         : '%(twitter_short_url)s'
+                    },
+                    'gplus' : {
+                        'status'            : '%(googleplus_status)s',
+                        'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(googleplus_dummy_image)s',
+                        'txt_info'          : '%(googleplus_info_text)s',
+                        'txt_gplus_off'     : '%(googleplus_disconnected)s',
+                        'txt_gplus_on'      : '%(googleplus_connected)s',
+                        'language'          : '%(language)s'
+                    },
+                    'linkedin' : {
+                        'status'            : '%(linkedin_status)s',
+                        'dummy_img'         : portal_url + '/++resource++xhostplus.social.images/%(linkedin_dummy_image)s',
+                        'txt_info'          : '%(linkedin_info_text)s',
+                        'txt_linkedin_off'  : '%(linkedin_disconnected)s',
+                        'txt_linkedin_on'   : '%(linkedin_connected)s',
+                        'language'          : '%(language)s'
+                    }
+                },
+                'txt_help'          : '%(txt_help)s',
+                'settings_perma'    : '%(settings_perma)s'
+             });
+          }
+        });
         """ % {
             'facebook_info_text' : self.context.translate(_(u'2 clicks for your privacy: Only if you click here the button will get active and you can send your recommendation to Facebook. An active button will send data do a third-party &ndash; more information on <em>i</em>.')),
             'facebook_disconnected' : self.context.translate(_(u'not connected to Facebook')),
@@ -137,6 +216,12 @@ class Buttons(ViewletBase):
             'linkedin_connected' : self.context.translate(_(u'connected to LinkedIn')),
             'language' : language,
             'facebook_language' : facebook_language,
+            'facebook_status' : self.facebook_status,
+            'twitter_status' : self.twitter_status,
+            'googleplus_status' : self.googleplus_status,
+            'linkedin_status' : self.linkedin_status,
+            'twitter_hashtags' : self.twitter_hashtags,
+            'twitter_short_url' : self.shorten_url(self.context.absolute_url()),
             'facebook_dummy_image' : self.context.translate(_(u'dummy_facebook_en.png')),
             'twitter_dummy_image' : self.context.translate(_(u'dummy_twitter_en.png')),
             'googleplus_dummy_image' : self.context.translate(_(u'dummy_googleplus_en.png')),
@@ -148,12 +233,19 @@ class Buttons(ViewletBase):
 
     def import_script(self):
         code = ""
-        scripts = [
-            self.get_facebook_script_url(),
-            self.get_googleplus_script_url(),
-            self.get_twitter_script_url(),
-            self.get_linkedin_script_url(),
-        ]
+        scripts = []
+
+        if self.facebook_status == 'on':
+            scripts.append(self.get_facebook_script_url())
+
+        if self.googleplus_status == 'on':
+            scripts.append(self.get_googleplus_script_url())
+
+        if self.twitter_status == 'on':
+            scripts.append(self.get_twitter_script_url())
+
+        if self.linkedin_status == 'on':
+            scripts.append(self.get_linkedin_script_url())
 
         for script in scripts:
             code += "xhostplus_social_inject_js(\"%(url)s\", \"%(inner_code)s\");\n" % {
